# Render CTL tool

![Author](https://img.shields.io/static/v1?label=author&message=1058449090@qq.com&color=blue)
![License](https://img.shields.io/github/license/penny1027/renderctl)
[![python](https://img.shields.io/static/v1?label=Python&message=3.8&color=3776AB)](https://www.python.org)
[![PyPI](https://img.shields.io/pypi/v/renderctl.svg)](https://pypi.org/project/renderctl/)

### Install
```bash
pip install renderctl
```

#### Usage
- Render yaml templates

```bash
renderctl yaml --config env.yaml --template templates --render render
```